==> haskell-oeis-0.3.10.1-76-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-oeis.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 oeis
version:              0.3.10.1
visibility:           public
id:                   oeis-0.3.10.1-1EE8cMBuXAvAhPJZVw5rqP
key:                  oeis-0.3.10.1-1EE8cMBuXAvAhPJZVw5rqP
license:              BSD-3-Clause
maintainer:           Bartosz Nitka <niteria@gmail.com>
author:               Brent Yorgey
stability:            experimental
synopsis:
    Interface to the Online Encyclopedia of Integer Sequences (OEIS)

description:
    Interface to the <http://oeis.org/ Online Encyclopedia of Integer Sequences (OEIS)>.

category:             Math
abi:                  d218ed08eccc074de99e8a87ac1cebef
exposed:              True
exposed-modules:      Math.OEIS Math.OEIS.Internal
hidden-modules:       Math.OEIS.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/oeis-0.3.10.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/oeis-0.3.10.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/oeis-0.3.10.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-oeis
hs-libraries:         HSoeis-0.3.10.1-1EE8cMBuXAvAhPJZVw5rqP
depends:
    base-4.17.2.1 http-client-0.7.18-IROMjfUUOqe2MZRLGJEp23
    http-client-tls-0.3.6.4-6ZcD1iDGS9Y6vJRxoNTqij
    http-types-0.12.4-B5DxmOwiWvxHN2hLvYjsdc
    network-3.1.4.0-KV3OkCyx0pcI1DdyD3ZbeB
    network-uri-2.6.4.2-2s4BpOjYszS9lLOXbJJXzp
    utf8-string-1.0.2-LQzUWC2hIN17FDKHsw4I2c

haddock-interfaces:   /usr/share/doc/haskell-oeis/html/oeis.haddock
haddock-html:         /usr/share/doc/haskell-oeis/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-oeis-0.3.10.1-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-oeis.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 oeis
version:              0.3.10.1
visibility:           public
id:                   oeis-0.3.10.1-9hnF4dEw0KFG4yZ2aC0cSg
key:                  oeis-0.3.10.1-9hnF4dEw0KFG4yZ2aC0cSg
license:              BSD-3-Clause
maintainer:           Bartosz Nitka <niteria@gmail.com>
author:               Brent Yorgey
stability:            experimental
synopsis:
    Interface to the Online Encyclopedia of Integer Sequences (OEIS)

description:
    Interface to the <http://oeis.org/ Online Encyclopedia of Integer Sequences (OEIS)>.

category:             Math
abi:                  c7831911e8e105c335c383f804cab297
exposed:              True
exposed-modules:      Math.OEIS Math.OEIS.Internal
hidden-modules:       Math.OEIS.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/oeis-0.3.10.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/oeis-0.3.10.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/oeis-0.3.10.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-oeis
hs-libraries:         HSoeis-0.3.10.1-9hnF4dEw0KFG4yZ2aC0cSg
depends:
    base-4.17.2.1 http-client-0.7.18-1ilMUdfjVEzBmOQGNnAaP8
    http-client-tls-0.3.6.4-8dChSegNH5N3bDZSPplmBY
    http-types-0.12.4-22ca4VB3NcX8GYX2Ium30U
    network-3.1.4.0-9WwAYDZyp2nAB4XV6sI63l
    network-uri-2.6.4.2-6QHuxl9r30A5vsu5UpWUoB
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:   /usr/share/doc/haskell-oeis/html/oeis.haddock
haddock-html:         /usr/share/doc/haskell-oeis/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
